@@ -1,11 +1,11 @@
 #' Reduce results from result directory.
 #'
+#' @description
 #' The following functions provide ways to reduce result files into either specific R objects (like
 #' vectors, lists, matrices or data.frames) or to arbitrarily aggregate them, which is a more general
 #' operation.
 #'
-#' @param reg [\code{\link{Registry}}]\cr
-#'   Registry.
+#' @template arg_reg
 #' @param ids [\code{integer}]\cr
 #'   Ids of selected jobs.
 #'   Default is all jobs for which results are available.
@@ -38,6 +38,7 @@
 #'   as argument \code{res} for jobs with missing results.\cr
 #'   For the specialized reduction functions \code{reduceResults[Type]}: If not missing, \code{impute.val} is
 #'   used as a replacement for the return value of \code{fun} on missing results.
+#' @template arg_progressbar
 #' @param rows [\code{logical(1)}]\cr
 #'   Should the selected vectors be used as rows (or columns) in the result matrix?
 #'   Default is \code{TRUE}.
@@ -55,6 +56,7 @@
 #' f = function(x) x^2
 #' batchMap(reg, f, 1:5)
 #' submitJobs(reg)
+#' waitForJobs(reg)
 #'
 #' # reduce results to a vector
 #' reduceResultsVector(reg)
@@ -65,6 +67,7 @@
 #' f = function(x) list(a = x, b = as.character(2*x), c = x^2)
 #' batchMap(reg, f, 1:5)
 #' submitJobs(reg)
+#' waitForJobs(reg)
 #'
 #' # reduce results to a vector
 #' reduceResultsVector(reg, fun = function(job, res) res$a)
@@ -79,9 +82,8 @@
 #' print(str(reduceResultsDataFrame(reg)))
 #' # reduce results to a sum
 #' reduceResults(reg, fun = function(aggr, job, res) aggr+res$a, init = 0)
-# FIXME we need more documentation for reduceResultsReturnValue ...
-reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val, ...) {
-  checkRegistry(reg)
+reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val, progressbar = TRUE, ...) {
+  checkRegistry(reg, writeable = FALSE)
   syncRegistry(reg)
   if (missing(ids)) {
     ids = done = dbFindDone(reg)
@@ -96,6 +98,7 @@ reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val,
     }
   }
   assertFunction(fun, c("aggr", "job", "res"))
+  assertFlag(progressbar)
 
   n = length(ids)
   info("Reducing ", n, " results...")
@@ -105,8 +108,7 @@ reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val,
     return(init)
   }
 
-  bar = makeProgressBar(max = n, label = "reduceResults")
-  bar$set()
+  bar = getProgressBar(progressbar, max = n, label = "reduceResults")
 
   tryCatch({
     if (missing(init)) {
@@ -118,12 +120,12 @@ reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val,
       aggr = init
     }
 
-    for (id in ids) {
+    not.done = (ids %nin% done)
+    for (i in seq_along(ids)) {
       # use lazy evaluation
       aggr = fun(aggr,
-                 job = dbGetJobs(reg, id)[[1L]],
-                 res = if (with.impute && id %nin% done)
-                   impute.val else getResult(reg, id, part),
+                 job = dbGetJobs(reg, ids[i])[[1L]],
+                 res = if (with.impute && not.done[i]) impute.val else getResult(reg, ids[i], part),
                  ...)
       bar$inc(1L)
     }
@@ -133,8 +135,9 @@ reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val,
 
 #' @export
 #' @rdname reduceResults
-reduceResultsList = function(reg, ids, part = NA_character_, fun, ..., use.names = "ids", impute.val) {
-  checkRegistry(reg)
+reduceResultsList = function(reg, ids, part = NA_character_, fun, ..., use.names = "ids",
+  impute.val, progressbar = TRUE) {
+  checkRegistry(reg, writeable = FALSE)
   syncRegistry(reg)
   if (missing(ids)) {
     ids = done = dbFindDone(reg)
@@ -153,6 +156,7 @@ reduceResultsList = function(reg, ids, part = NA_character_, fun, ..., use.names
   else
     assertFunction(fun, c("job", "res"))
   use.names = convertUseNames(use.names)
+  assertFlag(progressbar)
 
   n = length(ids)
   info("Reducing %i results...", n)
@@ -166,8 +170,7 @@ reduceResultsList = function(reg, ids, part = NA_character_, fun, ..., use.names
     it = seq_len(n)
   }
 
-  bar = makeProgressBar(max = n, label = "reduceResults")
-  bar$set()
+  bar = getProgressBar(progressbar, max = n, label = "reduceResults")
   tryCatch({
     for (i in it) {
       # use lazy evaluation!
@@ -222,5 +225,14 @@ reduceResultsDataFrame = function(reg, ids, part = NA_character_, fun, ..., use.
   if (!length(res))
     return(data.frame())
 
-  list2df(res, force.names = TRUE, strings.as.factors = strings.as.factors)
+  convertListOfRowsToDataFrame(res, strings.as.factors = strings.as.factors)
+}
+
+#' @export
+#' @rdname reduceResults
+reduceResultsDataTable = function(reg, ids, part = NA_character_, fun, ..., use.names = "ids", impute.val) {
+  res = reduceResultsList(reg, ids, part, fun, ..., use.names = use.names, impute.val = impute.val)
+  if (!length(res))
+    return(data.table())
+  rbindlist(res, fill = TRUE)
 }
